sug_sock

this is the sugsock library.
its suppose to extend the functionalty of the standart socket library, and be much more easy to use.
as of now its not in operating order, you are free to look at the files and come up with better soulutions or contact me if youd like.
